@@ -1,5 +1,4 @@
-RESOURCE_DASHBOARD = \
-r"""
+RESOURCE_DASHBOARD = r"""
 {
   "annotations": {
     "list": [
@@ -1513,4 +1512,4 @@ r"""
   "version": 2,
   "weekStart": ""
 }
-"""
\ No newline at end of file
+"""
